% Script MidiPlayer
% Interactive application for transforming and playing MIDI audio data.

% Print instructions for user
fprintf('MATLAB MIDI Player\n')
fprintf('Commands:\n')
fprintf('  L <filename>  : Load a MIDI log from a file\n')
fprintf('  W <filename>  : Write transformed MIDI log to file\n')
fprintf('  M <bpm>       : Change tempo\n')
fprintf('  T <semitones> : Transpose key\n')
fprintf('  P             : Play song\n')
fprintf('  Q             : Quit\n')

% Variables to store application state (command actions will read or write these)
origTempo= 0;  % Original tempo of last-loaded song [bpm]
notesByCh= {};  % Notes for each instrument in the current song
tempo= 0;  % Tempo to play song back at [bpm]
semitones= 0;  % Amount to transpose song when playing back [semitones]

% Prompt user for command until they quit
cmd= input('> ', 's');
while ~strcmp(cmd, 'Q')
    if length(cmd) >= 3 && strcmp(cmd(1:2), 'W ')
        % Write transformed file
        filename= cmd(3:end);
        for ch = 1:length(notesByCh)
            newNotes{ch}= transformNotes(notesByCh{ch}, tempo/origTempo, semitones);
        end
        writeMidiLog(newNotes, tempo, filename)
    % TODO: Implement remaining command handlers
    else
        fprintf('Unknown command; try again\n')
    end
    cmd= input('> ', 's');
end

fprintf('Bye bye\n');
