classdef Note < handle
    % Represent a musical note played at a certain time for a certain
    % duration with a specified pitch and amplitude.
    
    properties
        time  % Time from start of song at which note is struck [s]
        duration  % Duration of time that note is held before being released [s]
        frequency  % Fundadmental frequency of note (pitch) [Hz]
        amplitude  % Maximum amplitude of note's waveform (between 0 and 1)
    end
    
    methods
        function obj = Note(t, dt, f, a)
            % Construct a Note played at time `t` [s] for a duration of
            % `dt` [s] with a fundamental frequency of `f` [Hz] and an
            % amplitude of `a`.
            obj.time = t;
            obj.duration = dt;
            obj.frequency = f;
            obj.amplitude = a;
        end
    end
end
